==> apigateway-1.22.0-sources.jar: software/amazon/awscdk/services/apigateway/Stage.java <==
package software.amazon.awscdk.services.apigateway;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.21.2 (build 4370756)", date = "2020-01-23T18:16:57.664Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.Stage")
public class Stage extends software.amazon.awscdk.core.Resource {

    protected Stage(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Stage(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public Stage(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.apigateway.StageProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Returns the invoke URL for a certain path.
     * <p>
     * @param path The resource path.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String urlForPath(final java.lang.String path) {
        return this.jsiiCall("urlForPath", java.lang.String.class, new Object[] { path });
    }

    /**
     * Returns the invoke URL for a certain path.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String urlForPath() {
        return this.jsiiCall("urlForPath", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.services.apigateway.IRestApi getRestApi() {
        return this.jsiiGet("restApi", software.amazon.awscdk.services.apigateway.IRestApi.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getStageName() {
        return this.jsiiGet("stageName", java.lang.String.class);
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.apigateway.Stage}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.apigateway.StageProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.apigateway.StageProps.Builder();
        }

        /**
         * Indicates whether the cached responses are encrypted.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param cacheDataEncrypted Indicates whether the cached responses are encrypted. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cacheDataEncrypted(final java.lang.Boolean cacheDataEncrypted) {
            this.props.cacheDataEncrypted(cacheDataEncrypted);
            return this;
        }

        /**
         * Specifies the time to live (TTL), in seconds, for cached responses.
         * <p>
         * The
         * higher the TTL, the longer the response will be cached.
         * <p>
         * Default: Duration.minutes(5)
         * <p>
         * @return {@code this}
         * @see https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-caching.html
         * @param cacheTtl Specifies the time to live (TTL), in seconds, for cached responses. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cacheTtl(final software.amazon.awscdk.core.Duration cacheTtl) {
            this.props.cacheTtl(cacheTtl);
            return this;
        }

        /**
         * Specifies whether responses should be cached and returned for requests.
         * <p>
         * A
         * cache cluster must be enabled on the stage for responses to be cached.
         * <p>
         * Default: - Caching is Disabled.
         * <p>
         * @return {@code this}
         * @param cachingEnabled Specifies whether responses should be cached and returned for requests. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cachingEnabled(final java.lang.Boolean cachingEnabled) {
            this.props.cachingEnabled(cachingEnabled);
            return this;
        }

        /**
         * Specifies whether data trace logging is enabled for this method, which effects the log entries pushed to Amazon CloudWatch Logs.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param dataTraceEnabled Specifies whether data trace logging is enabled for this method, which effects the log entries pushed to Amazon CloudWatch Logs. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder dataTraceEnabled(final java.lang.Boolean dataTraceEnabled) {
            this.props.dataTraceEnabled(dataTraceEnabled);
            return this;
        }

        /**
         * Specifies the logging level for this method, which effects the log entries pushed to Amazon CloudWatch Logs.
         * <p>
         * Default: - Off
         * <p>
         * @return {@code this}
         * @param loggingLevel Specifies the logging level for this method, which effects the log entries pushed to Amazon CloudWatch Logs. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder loggingLevel(final software.amazon.awscdk.services.apigateway.MethodLoggingLevel loggingLevel) {
            this.props.loggingLevel(loggingLevel);
            return this;
        }

        /**
         * Specifies whether Amazon CloudWatch metrics are enabled for this method.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param metricsEnabled Specifies whether Amazon CloudWatch metrics are enabled for this method. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metricsEnabled(final java.lang.Boolean metricsEnabled) {
            this.props.metricsEnabled(metricsEnabled);
            return this;
        }

        /**
         * Specifies the throttling burst limit.
         * <p>
         * The total rate of all requests in your AWS account is limited to 5,000 requests.
         * <p>
         * Default: - No additional restriction.
         * <p>
         * @return {@code this}
         * @see https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-request-throttling.html
         * @param throttlingBurstLimit Specifies the throttling burst limit. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder throttlingBurstLimit(final java.lang.Number throttlingBurstLimit) {
            this.props.throttlingBurstLimit(throttlingBurstLimit);
            return this;
        }

        /**
         * Specifies the throttling rate limit.
         * <p>
         * The total rate of all requests in your AWS account is limited to 10,000 requests per second (rps).
         * <p>
         * Default: - No additional restriction.
         * <p>
         * @return {@code this}
         * @see https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-request-throttling.html
         * @param throttlingRateLimit Specifies the throttling rate limit. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder throttlingRateLimit(final java.lang.Number throttlingRateLimit) {
            this.props.throttlingRateLimit(throttlingRateLimit);
            return this;
        }

        /**
         * Indicates whether cache clustering is enabled for the stage.
         * <p>
         * Default: - Disabled for the stage.
         * <p>
         * @return {@code this}
         * @param cacheClusterEnabled Indicates whether cache clustering is enabled for the stage. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cacheClusterEnabled(final java.lang.Boolean cacheClusterEnabled) {
            this.props.cacheClusterEnabled(cacheClusterEnabled);
            return this;
        }

        /**
         * The stage's cache cluster size.
         * <p>
         * Default: 0.5
         * <p>
         * @return {@code this}
         * @param cacheClusterSize The stage's cache cluster size. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cacheClusterSize(final java.lang.String cacheClusterSize) {
            this.props.cacheClusterSize(cacheClusterSize);
            return this;
        }

        /**
         * The identifier of the client certificate that API Gateway uses to call your integration endpoints in the stage.
         * <p>
         * Default: - None.
         * <p>
         * @return {@code this}
         * @param clientCertificateId The identifier of the client certificate that API Gateway uses to call your integration endpoints in the stage. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder clientCertificateId(final java.lang.String clientCertificateId) {
            this.props.clientCertificateId(clientCertificateId);
            return this;
        }

        /**
         * A description of the purpose of the stage.
         * <p>
         * Default: - No description.
         * <p>
         * @return {@code this}
         * @param description A description of the purpose of the stage. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(final java.lang.String description) {
            this.props.description(description);
            return this;
        }

        /**
         * The version identifier of the API documentation snapshot.
         * <p>
         * Default: - No documentation version.
         * <p>
         * @return {@code this}
         * @param documentationVersion The version identifier of the API documentation snapshot. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder documentationVersion(final java.lang.String documentationVersion) {
            this.props.documentationVersion(documentationVersion);
            return this;
        }

        /**
         * Method deployment options for specific resources/methods.
         * <p>
         * These will
         * override common options defined in <code>StageOptions#methodOptions</code>.
         * <p>
         * Default: - Common options will be used.
         * <p>
         * @return {@code this}
         * @param methodOptions Method deployment options for specific resources/methods. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder methodOptions(final java.util.Map<java.lang.String, software.amazon.awscdk.services.apigateway.MethodDeploymentOptions> methodOptions) {
            this.props.methodOptions(methodOptions);
            return this;
        }

        /**
         * The name of the stage, which API Gateway uses as the first path segment in the invoked Uniform Resource Identifier (URI).
         * <p>
         * Default: - "prod"
         * <p>
         * @return {@code this}
         * @param stageName The name of the stage, which API Gateway uses as the first path segment in the invoked Uniform Resource Identifier (URI). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder stageName(final java.lang.String stageName) {
            this.props.stageName(stageName);
            return this;
        }

        /**
         * Specifies whether Amazon X-Ray tracing is enabled for this method.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param tracingEnabled Specifies whether Amazon X-Ray tracing is enabled for this method. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tracingEnabled(final java.lang.Boolean tracingEnabled) {
            this.props.tracingEnabled(tracingEnabled);
            return this;
        }

        /**
         * A map that defines the stage variables.
         * <p>
         * Variable names must consist of
         * alphanumeric characters, and the values must match the following regular
         * expression: [A-Za-z0-9-._~:/?#&amp;=,]+.
         * <p>
         * Default: - No stage variables.
         * <p>
         * @return {@code this}
         * @param variables A map that defines the stage variables. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder variables(final java.util.Map<java.lang.String, java.lang.String> variables) {
            this.props.variables(variables);
            return this;
        }

        /**
         * The deployment that this stage points to [disable-awslint:ref-via-interface].
         * <p>
         * @return {@code this}
         * @param deployment The deployment that this stage points to [disable-awslint:ref-via-interface]. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deployment(final software.amazon.awscdk.services.apigateway.Deployment deployment) {
            this.props.deployment(deployment);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.apigateway.Stage}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.services.apigateway.Stage build() {
            return new software.amazon.awscdk.services.apigateway.Stage(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> apigateway-1.24.0-sources.jar: software/amazon/awscdk/services/apigateway/Stage.java <==
package software.amazon.awscdk.services.apigateway;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.22.0 (build 14afdde)", date = "2020-02-13T18:54:13.513Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.Stage")
public class Stage extends software.amazon.awscdk.core.Resource {

    protected Stage(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Stage(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public Stage(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.StageProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Returns the invoke URL for a certain path.
     * <p>
     * @param path The resource path.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String urlForPath(final @org.jetbrains.annotations.Nullable java.lang.String path) {
        return this.jsiiCall("urlForPath", java.lang.String.class, new Object[] { path });
    }

    /**
     * Returns the invoke URL for a certain path.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String urlForPath() {
        return this.jsiiCall("urlForPath", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.IRestApi getRestApi() {
        return this.jsiiGet("restApi", software.amazon.awscdk.services.apigateway.IRestApi.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getStageName() {
        return this.jsiiGet("stageName", java.lang.String.class);
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.apigateway.Stage}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.apigateway.StageProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.apigateway.StageProps.Builder();
        }

        /**
         * Indicates whether the cached responses are encrypted.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param cacheDataEncrypted Indicates whether the cached responses are encrypted. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cacheDataEncrypted(final java.lang.Boolean cacheDataEncrypted) {
            this.props.cacheDataEncrypted(cacheDataEncrypted);
            return this;
        }

        /**
         * Specifies the time to live (TTL), in seconds, for cached responses.
         * <p>
         * The
         * higher the TTL, the longer the response will be cached.
         * <p>
         * Default: Duration.minutes(5)
         * <p>
         * @return {@code this}
         * @see https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-caching.html
         * @param cacheTtl Specifies the time to live (TTL), in seconds, for cached responses. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cacheTtl(final software.amazon.awscdk.core.Duration cacheTtl) {
            this.props.cacheTtl(cacheTtl);
            return this;
        }

        /**
         * Specifies whether responses should be cached and returned for requests.
         * <p>
         * A
         * cache cluster must be enabled on the stage for responses to be cached.
         * <p>
         * Default: - Caching is Disabled.
         * <p>
         * @return {@code this}
         * @param cachingEnabled Specifies whether responses should be cached and returned for requests. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cachingEnabled(final java.lang.Boolean cachingEnabled) {
            this.props.cachingEnabled(cachingEnabled);
            return this;
        }

        /**
         * Specifies whether data trace logging is enabled for this method, which effects the log entries pushed to Amazon CloudWatch Logs.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param dataTraceEnabled Specifies whether data trace logging is enabled for this method, which effects the log entries pushed to Amazon CloudWatch Logs. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder dataTraceEnabled(final java.lang.Boolean dataTraceEnabled) {
            this.props.dataTraceEnabled(dataTraceEnabled);
            return this;
        }

        /**
         * Specifies the logging level for this method, which effects the log entries pushed to Amazon CloudWatch Logs.
         * <p>
         * Default: - Off
         * <p>
         * @return {@code this}
         * @param loggingLevel Specifies the logging level for this method, which effects the log entries pushed to Amazon CloudWatch Logs. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder loggingLevel(final software.amazon.awscdk.services.apigateway.MethodLoggingLevel loggingLevel) {
            this.props.loggingLevel(loggingLevel);
            return this;
        }

        /**
         * Specifies whether Amazon CloudWatch metrics are enabled for this method.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param metricsEnabled Specifies whether Amazon CloudWatch metrics are enabled for this method. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder metricsEnabled(final java.lang.Boolean metricsEnabled) {
            this.props.metricsEnabled(metricsEnabled);
            return this;
        }

        /**
         * Specifies the throttling burst limit.
         * <p>
         * The total rate of all requests in your AWS account is limited to 5,000 requests.
         * <p>
         * Default: - No additional restriction.
         * <p>
         * @return {@code this}
         * @see https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-request-throttling.html
         * @param throttlingBurstLimit Specifies the throttling burst limit. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder throttlingBurstLimit(final java.lang.Number throttlingBurstLimit) {
            this.props.throttlingBurstLimit(throttlingBurstLimit);
            return this;
        }

        /**
         * Specifies the throttling rate limit.
         * <p>
         * The total rate of all requests in your AWS account is limited to 10,000 requests per second (rps).
         * <p>
         * Default: - No additional restriction.
         * <p>
         * @return {@code this}
         * @see https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-request-throttling.html
         * @param throttlingRateLimit Specifies the throttling rate limit. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder throttlingRateLimit(final java.lang.Number throttlingRateLimit) {
            this.props.throttlingRateLimit(throttlingRateLimit);
            return this;
        }

        /**
         * Indicates whether cache clustering is enabled for the stage.
         * <p>
         * Default: - Disabled for the stage.
         * <p>
         * @return {@code this}
         * @param cacheClusterEnabled Indicates whether cache clustering is enabled for the stage. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cacheClusterEnabled(final java.lang.Boolean cacheClusterEnabled) {
            this.props.cacheClusterEnabled(cacheClusterEnabled);
            return this;
        }

        /**
         * The stage's cache cluster size.
         * <p>
         * Default: 0.5
         * <p>
         * @return {@code this}
         * @param cacheClusterSize The stage's cache cluster size. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cacheClusterSize(final java.lang.String cacheClusterSize) {
            this.props.cacheClusterSize(cacheClusterSize);
            return this;
        }

        /**
         * The identifier of the client certificate that API Gateway uses to call your integration endpoints in the stage.
         * <p>
         * Default: - None.
         * <p>
         * @return {@code this}
         * @param clientCertificateId The identifier of the client certificate that API Gateway uses to call your integration endpoints in the stage. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder clientCertificateId(final java.lang.String clientCertificateId) {
            this.props.clientCertificateId(clientCertificateId);
            return this;
        }

        /**
         * A description of the purpose of the stage.
         * <p>
         * Default: - No description.
         * <p>
         * @return {@code this}
         * @param description A description of the purpose of the stage. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(final java.lang.String description) {
            this.props.description(description);
            return this;
        }

        /**
         * The version identifier of the API documentation snapshot.
         * <p>
         * Default: - No documentation version.
         * <p>
         * @return {@code this}
         * @param documentationVersion The version identifier of the API documentation snapshot. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder documentationVersion(final java.lang.String documentationVersion) {
            this.props.documentationVersion(documentationVersion);
            return this;
        }

        /**
         * Method deployment options for specific resources/methods.
         * <p>
         * These will
         * override common options defined in <code>StageOptions#methodOptions</code>.
         * <p>
         * Default: - Common options will be used.
         * <p>
         * @return {@code this}
         * @param methodOptions Method deployment options for specific resources/methods. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder methodOptions(final java.util.Map<java.lang.String, software.amazon.awscdk.services.apigateway.MethodDeploymentOptions> methodOptions) {
            this.props.methodOptions(methodOptions);
            return this;
        }

        /**
         * The name of the stage, which API Gateway uses as the first path segment in the invoked Uniform Resource Identifier (URI).
         * <p>
         * Default: - "prod"
         * <p>
         * @return {@code this}
         * @param stageName The name of the stage, which API Gateway uses as the first path segment in the invoked Uniform Resource Identifier (URI). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder stageName(final java.lang.String stageName) {
            this.props.stageName(stageName);
            return this;
        }

        /**
         * Specifies whether Amazon X-Ray tracing is enabled for this method.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param tracingEnabled Specifies whether Amazon X-Ray tracing is enabled for this method. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tracingEnabled(final java.lang.Boolean tracingEnabled) {
            this.props.tracingEnabled(tracingEnabled);
            return this;
        }

        /**
         * A map that defines the stage variables.
         * <p>
         * Variable names must consist of
         * alphanumeric characters, and the values must match the following regular
         * expression: [A-Za-z0-9-._~:/?#&amp;=,]+.
         * <p>
         * Default: - No stage variables.
         * <p>
         * @return {@code this}
         * @param variables A map that defines the stage variables. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder variables(final java.util.Map<java.lang.String, java.lang.String> variables) {
            this.props.variables(variables);
            return this;
        }

        /**
         * The deployment that this stage points to [disable-awslint:ref-via-interface].
         * <p>
         * @return {@code this}
         * @param deployment The deployment that this stage points to [disable-awslint:ref-via-interface]. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deployment(final software.amazon.awscdk.services.apigateway.Deployment deployment) {
            this.props.deployment(deployment);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.apigateway.Stage}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.services.apigateway.Stage build() {
            return new software.amazon.awscdk.services.apigateway.Stage(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
